@@ -9,8 +9,7 @@ import pandas as pd
 
 sys.path.append(os.path.dirname(os.path.abspath(os.path.dirname(__file__))))
 
-from fast_hangle_levenshtein import *
-
+from ._index import LevenshteinIndex # edit distance
 from . import CustomModel
 from . import Jamo
 
